Permuted Congruential Generator (64-bit, PCG64 DXSM)
----------------------------------------------------

.. currentmodule:: numpy.random

.. autoclass:: PCG64DXSM
    :members: __init__
    :exclude-members: __init__

State
=====

.. autosummary::
   :toctree: generated/

   ~PCG64DXSM.state

Parallel generation
===================
.. autosummary::
   :toctree: generated/

   ~PCG64DXSM.advance
   ~PCG64DXSM.jumped

Extending
=========
.. autosummary::
   :toctree: generated/

   ~PCG64DXSM.cffi
   ~PCG64DXSM.ctypes
